# Feedback 💙 We've been humbled and energized by the positive community response to Marvin.

> Tired: write comments to prompt copilot to write code.
> Wired: just write comments.
> it's cleaner :D https://t.co/FOA26lR9xN

> — Andrej Karpathy (@karpathy) March 30, 2023

> Ok, I admit, I’m getting more and more hyped about @AskMarvinAI. Some of these new functions are pretty legit looking. https://t.co/xhCCKp5kU5

> — Chris Riccomini 🏖️ (@criccomini) April 21, 2023

> even the way ai_model uses ai_fn is chefs kiss, truely a craftsmanhttps://t.co/GcmWDeEVJS
> They have spinner text.

> — jason (@jxnlco) May 12, 2023

> The library is open-source: @AskMarvinAI, by @jlowin
> `@ai_model` is not the only magic Python decorator. There is also `@ai_fn` that makes any function an ambient LLM processor.https://t.co/ZXElyA0Ihp

> — Jim Fan (@DrJimFan) May 14, 2023

> This is f**king cool. https://t.co/4PH6VAZPYo

> — Pydantic (@pydantic) May 14, 2023

> Pretty slick… get Pydantic models from a string of Text. https://t.co/EnnQkzl4Ay

> — Chris Riccomini 🏖️ (@criccomini) May 12, 2023

> Uhh how are people not talking about @AskMarvinAI more? @ai_fn is 🤯

> — Rushabh Doshi (@radoshi) May 18, 2023